/*
 * 
 *  This file is part of Sourceprojects.org Lycia Copyright 2010 noctarius
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * 
 */
package org.sourceprojects.lycia.osgi.test.impl;

import org.sourceprojects.lycia.AbstractTagParser;
import org.sourceprojects.lycia.DefinitionBuilder;
import org.sourceprojects.lycia.ParserContext;
import org.sourceprojects.lycia.exceptions.LyciaParsingException;
import org.w3c.dom.Element;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;

public class InputTagParser extends AbstractTagParser<StringBuilder> {
	private static final String NAMESPACEURI = "http://www.example.com/schema/tags";
	private static final String[] TAGS = {
		"input"
	};
	
	@Override
	public String getNamespace() {
		return NAMESPACEURI;
	}

	@Override
	public String[] getTags() {
		return TAGS;
	}

	@Override
	public void parseElement(Element element, ParserContext<StringBuilder> parserContext,
			DefinitionBuilder definitionBuilder) throws LyciaParsingException {
		
		if ("upload".equals(parserContext.getParserState())) {
			StringBuilder buffer = parserContext.getContextObject();

			buffer.append("<").append(element.getNodeName());
			NamedNodeMap map = element.getAttributes();
			for (int i = 0; i < map.getLength(); i++) {
				Node node = map.item(i);
				buffer.append(node.getLocalName()).append("=\"").append(
						node.getNodeValue()).append("\" ");
			}
			buffer.append("/>");
		}
		
		super.parseElement(element, parserContext, definitionBuilder);
	}
	
	@Override
	public Node transformElement(Element element, ParserContext<StringBuilder> parserContext,
			DefinitionBuilder definitionBuilder)
			throws LyciaParsingException {
		
		if ("upload".equals(parserContext.getParserState())) {
			String id = element.getAttribute("id");
			
			Element e = definitionBuilder.getDocument().createElement("example:output");
			e.setAttribute("id", id);
			e.setAttribute("language", "en-EN");
			
			return e;
		}	
			
		return super.transformElement(element, parserContext, definitionBuilder);
	}
	
}
