/*
 * 
 *  This file is part of Sourceprojects.org Lycia Copyright 2010 noctarius
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * 
 */
package org.sourceprojects.lycia.osgi.test.impl;

import java.io.InputStream;

import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.sourceprojects.lycia.ResourceResolver;
import org.sourceprojects.lycia.LyciaParser;
import org.sourceprojects.lycia.LyciaOsgiFactory;
import org.sourceprojects.lycia.exceptions.LyciaInitializationException;
import org.sourceprojects.lycia.exceptions.LyciaParsingException;
import org.sourceprojects.lycia.osgi.test.TestService;

public class TestServiceImpl implements TestService {
	private final BundleContext bundleContext;
	
	public TestServiceImpl(BundleContext bundleContext) {
		this.bundleContext = bundleContext;
	}
	
	@Override
	public String testOsgiService() throws LyciaParsingException {
		ServiceReference reference = bundleContext.getServiceReference(LyciaOsgiFactory.class.getName());
		
		if (reference == null)
			throw new LyciaInitializationException("ServiceReference not found");
		
		LyciaOsgiFactory factory = (LyciaOsgiFactory) bundleContext.getService(reference);
		
		LyciaParser<StringBuilder> parser = factory.newParserInstance();

		ResourceResolver resolver = factory.newResourceResolverInstance();
		StringBuilder buffer = new StringBuilder();

		parser.getParserContext().setContextObject(buffer);
		parser.setResourceResolver(resolver);
		parser.addTagDefinitionParser(new XHTMLTagParser());
		parser.addTagDefinitionParser(new BaseBodyTagParser());
		parser.addTagDefinitionParser(new InputTagParser());

		parser.getParserContext().setParserState("upload");

		InputStream is = getClass().getClassLoader().getResourceAsStream(
				"test.xml");

		parser.parse(is);

		bundleContext.ungetService(reference);
		return parser.getParserContext().getContextObject().toString();
	}

}
